package sessionuserdatanullapp.view.util;

import oracle.adf.controller.ControllerContext;
import oracle.adf.controller.TaskFlowContext;
import oracle.adf.controller.TaskFlowId;
import oracle.adf.controller.ViewPortContext;
import oracle.adf.controller.binding.BindingUtils;
import oracle.adf.controller.internal.metadata.DataControlScopeType;
import oracle.adf.controller.internal.metadata.MetadataService;
import oracle.adf.controller.internal.metadata.TaskFlowDefinition;
import oracle.adf.controller.internal.metadata.TransactionType;
import oracle.adf.model.BindingContext;
import oracle.adf.model.DataControlFrame;

/**
 * some methods based on code written by Chris Muir in TaskFlowUtils.java
 * at http://download.oracle.com/otn_hosted_doc/jdeveloper/11gdemos/ADFTransactionFundamentalsCompleteSeparateTransactions.zip
 */
public class ADFHelper
{
	protected ADFHelper()
	{
		super();
	}

	public static TaskFlowId getCurrentTaskFlowId()
	{
		ControllerContext vControllerContext = ControllerContext.getInstance();
		ViewPortContext vCurrentViewPort = vControllerContext.getCurrentViewPort();
		TaskFlowContext vTaskFlowContext = vCurrentViewPort.getTaskFlowContext();
		return vTaskFlowContext.getTaskFlowId();	
	}

	public static String getTaskFlowName()
	{
		MetadataService vMetadataService = MetadataService.getInstance();
		TaskFlowId vCurrentTaskFlowId = getCurrentTaskFlowId();
		if (vCurrentTaskFlowId == null)
		{
			return "(no current TaskFlowId)";
		}
		TaskFlowDefinition vTaskFlowDefinition =
			vMetadataService.getTaskFlowDefinition(vCurrentTaskFlowId);
		if (vTaskFlowDefinition != null)
		{
			TaskFlowId vTaskFlowId = vTaskFlowDefinition.getTaskFlowId();
			if (vTaskFlowId != null)
			{
				return vTaskFlowId.getFullyQualifiedName();
			}
			else
			{
				return "(no TaskFlowId)";
			}
		}
		else
		{
			return "(no TaskFlowDefinition)";
		}
	}

	public static String getTaskFlowUsePageFragmentsName()
	{
		MetadataService vMetadataService = MetadataService.getInstance();
		TaskFlowId vCurrentTaskFlowId = getCurrentTaskFlowId();
		if (vCurrentTaskFlowId == null)
		{
			return "unbounded task-flow pages";
		}
		TaskFlowDefinition vTaskFlowDefinition =
			vMetadataService.getTaskFlowDefinition(vCurrentTaskFlowId);
		if (vTaskFlowDefinition != null)
		{
			if (vTaskFlowDefinition.usePageFragments())
			{
				return "use page-fragments";
			}
			else
			{
				return "no page-fragments";
			}
		}
		else
		{
			return "(no TaskFlowDefinition)";
		}
	}

	public static String getTaskFlowDataControlScopeTypeName()
	{
		MetadataService vMetadataService = MetadataService.getInstance();
		TaskFlowId vCurrentTaskFlowId = getCurrentTaskFlowId();
		if (vCurrentTaskFlowId == null)
		{
			return "(no current TaskFlowId)";
		}
		TaskFlowDefinition vTaskFlowDefinition =
			vMetadataService.getTaskFlowDefinition(vCurrentTaskFlowId);
		if (vTaskFlowDefinition != null)
		{
			DataControlScopeType vDataControlScopeType =
				vTaskFlowDefinition.getDataControlScopeType();
			
			if (vDataControlScopeType == null)
			{
				return "shared DataControlScopeType (null)";
			}
			else if (vDataControlScopeType == DataControlScopeType.SHARED)
			{
				return "shared DataControlScopeType";
			}
			else if (vDataControlScopeType == DataControlScopeType.ISOLATED)
			{
				return "isolated DataControlScopeType";
			}
			else
			{
				return "unknown DataControlScopeType (" + vDataControlScopeType + ")";
			}
		}
		else
		{
			return "(no TaskFlowDefinition)";
		}
	}

	public static String getTaskFlowTransactionTypeName()
	{
		MetadataService vMetadataService = MetadataService.getInstance();
		TaskFlowId vCurrentTaskFlowId = getCurrentTaskFlowId();
		if (vCurrentTaskFlowId == null)
		{
			return "(no current TaskFlowId)";
		}
		TaskFlowDefinition vTaskFlowDefinition =
			vMetadataService.getTaskFlowDefinition(vCurrentTaskFlowId);
		if (vTaskFlowDefinition != null)
		{
			TransactionType vTransactionType = vTaskFlowDefinition.getTransactionType();
			
			if (vTransactionType == null)
			{
				return "-No Controller Transaction-";
			}
			else if (vTransactionType == TransactionType.NEW_TRANSACTION)
			{
				return "Always Begin New Transaction";
			}
			else if (vTransactionType == TransactionType.REQUIRES_EXISTING_TRANSACTION)
			{
				return "Always Use Existing Transaction";
			}
			else if (vTransactionType == TransactionType.REQUIRES_TRANSACTION)
			{
				return "Use Existing Transaction if Possible";
			}
			else
			{
				return "unknown TransactionType (" + vTransactionType + ")";
			}
		}
		else
		{
			return "(no TaskFlowDefinition)";
		}
	}

	public static String getDataControlFrameName()
	{
		BindingContext vBindingContext = BindingUtils.getBindingContext();
		return vBindingContext.getCurrentDataControlFrame();
	}

	public static DataControlFrame getDataControlFrame()
	{
		BindingContext vBindingContext = BindingUtils.getBindingContext();
		String vCurrentDataControlFrameName =
			vBindingContext.getCurrentDataControlFrame();
		return vBindingContext.findDataControlFrame(vCurrentDataControlFrameName);
	}

	public static boolean isDataControlFrameTransactionDirty()
	{
		return getDataControlFrame().isTransactionDirty();
	}

	public static String getDataControlFrameOpenTransactionName()
	{
		return getDataControlFrame().getOpenTransactionName();
	}
}
